#
# spec file for package rp-pppoe
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org
#

%define _name pppoe
%define _group dialout
Name:           rp-%{_name}
Version:        3.12
Release:        lp152.6.37
Summary:        A PPP Over Ethernet Redirector for PPPD
License:        GPL-2.0+
Group:          Productivity/Networking/PPP
URL:            https://www.roaringpenguin.com/products/pppoe
Source0:        https://www.roaringpenguin.com/files/download/%{name}-%{version}.tar.gz
Source1:        %{_name}-connect
Source2:        %{_name}-setup
Source3:        %{_name}-start
Source4:        %{_name}-status
Source5:        %{_name}-stop
Source6:        %{_name}.service
Source7:        %{_name}-server.service
Patch0:         docdir.diff
Patch1:         nonrfc-modems.diff
Patch2:         release-buildsystem.diff
Patch3:         resolve-conf.diff
Patch4:         %{name}-3.10-config.patch
Patch5:         %{name}-3.10-init.patch
Patch6:         %{name}-pie.patch
Patch7:         strip.diff
BuildRequires:  ppp
BuildRequires:  systemd
Requires:       net-tools
Requires:       ppp
Requires(post): permissions
%if 0%{?suse_version} >= 1330
Requires:       group(%{_group})
Requires(pre):  group(%{_group})
%else
Requires(pre):  shadow
%endif

%description
%{name} is a user-space redirector which permits the use of PPPoE
(Point-to-Point Protocol Over Ethernet) with Linux. PPPoE is used by
many ADSL service providers.

%prep
%setup -q
%patch0
%patch1
%patch2
%patch3
%patch4 -p1
%patch5 -p1
%patch6
%patch7

%build
cd src
%configure
make %{?_smp_mflags}
cd ../gui
make %{?_smp_mflags}

%install
%make_install -C src
mkdir -p %{buildroot}%{_sbindir} %{buildroot}%{_unitdir}
install -m 0755 %{SOURCE1} %{buildroot}%{_sbindir}
install -m 0755 %{SOURCE2} %{buildroot}%{_sbindir}
install -m 0755 %{SOURCE3} %{buildroot}%{_sbindir}
install -m 0755 %{SOURCE4} %{buildroot}%{_sbindir}
install -m 0755 %{SOURCE5} %{buildroot}%{_sbindir}
install -m 0644 %{SOURCE6} %{buildroot}%{_unitdir}/%{_name}.service
install -m 0644 %{SOURCE7} %{buildroot}%{_unitdir}/%{_name}-server.service
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{_name}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{_name}-server
ln -sf %{_name}-stop %{buildroot}%{_sbindir}/adsl-stop
ln -sf %{_name}-start %{buildroot}%{_sbindir}/adsl-start
rm -rf %{buildroot}%{_sysconfdir}/ppp/%{_name}.conf \
       %{buildroot}%{_sysconfdir}/rc.d/init.d/%{_name} \
       %{buildroot}%{_initddir}
%make_install -C gui
install -d  %{buildroot}%{_defaultdocdir}/%{name}
mv %{buildroot}%{_sysconfdir}/ppp/plugins/README %{buildroot}%{_defaultdocdir}/%{name}/README.plugins
rm -rf %{buildroot}%{_sysconfdir}/ppp/plugins

%pre
%if 0%{?suse_version} < 1330
getent group %{_group} >/dev/null || %{_sbindir}/groupadd -r %{_group}
%endif
%service_add_pre %{_name}.service
%service_add_pre %{_name}-server.service

%preun
%service_del_preun %{_name}.service
%service_del_preun %{_name}-server.service

%post
%service_add_post %{_name}.service
%service_add_post %{_name}-server.service
%set_permissions %{_sbindir}/%{_name}-wrapper

%postun
%service_del_postun %{_name}.service
%service_del_postun %{_name}-server.service

%verifyscript
%verify_permissions -e %{_sbindir}/%{_name}-wrapper

%files
%dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/*
%config(noreplace) %{_sysconfdir}/ppp/%{_name}-server-options
%config(noreplace) %{_sysconfdir}/ppp/firewall-masq
%config(noreplace) %{_sysconfdir}/ppp/firewall-standalone
%{_bindir}/tkpppoe
%{_sbindir}/%{_name}
%{_sbindir}/%{_name}-server
%{_sbindir}/%{_name}-sniff
%{_sbindir}/%{_name}-relay
%{_sbindir}/%{_name}-connect
%{_sbindir}/%{_name}-start
%{_sbindir}/%{_name}-stop
%{_sbindir}/%{_name}-setup
%{_sbindir}/%{_name}-status
%attr (4750,root,dialout) %{_sbindir}/%{_name}-wrapper
%{_mandir}/man5/%{_name}.conf.5*
%{_mandir}/man8/%{_name}.8*
%{_mandir}/man8/%{_name}-server.8*
%{_mandir}/man8/%{_name}-relay.8*
%{_mandir}/man8/%{_name}-sniff.8*
%{_mandir}/man8/%{_name}-connect.8*
%{_mandir}/man8/%{_name}-start.8*
%{_mandir}/man8/%{_name}-stop.8*
%{_mandir}/man8/%{_name}-status.8*
%{_mandir}/man8/%{_name}-setup.8*
%{_sbindir}/adsl-start
%{_sbindir}/adsl-stop
%{_sbindir}/rc%{_name}
%{_sbindir}/rc%{_name}-server
%{_unitdir}/%{_name}.service
%{_unitdir}/%{_name}-server.service
%dir %{_sysconfdir}/ppp/%{name}-gui
%{_mandir}/man1/tk%{_name}.1*
%{_mandir}/man1/%{_name}-wrapper.1*
%dir %{_datarootdir}/tk%{_name}
%{_datarootdir}/tk%{_name}/tk%{_name}.html
%{_datarootdir}/tk%{_name}/mainwin-busy.png
%{_datarootdir}/tk%{_name}/mainwin-nonroot.png
%{_datarootdir}/tk%{_name}/mainwin.png
%{_datarootdir}/tk%{_name}/props-advanced.png
%{_datarootdir}/tk%{_name}/props-basic.png
%{_datarootdir}/tk%{_name}/props-nic.png
%{_datarootdir}/tk%{_name}/props-options.png
%{_datarootdir}/tk%{_name}/en.msg
%{_datarootdir}/tk%{_name}/ja.msg
%verify(not mode caps) %attr(4750,root,dialout) %{_sbindir}/%{_name}-wrapper

%changelog
* Thu Nov 23 2017 ilya@ilya.pp.ua
- Add Requires/Requires(pre) group(dialout) (boo#1067511).
- Add %%verify_permissions script for pppoe-wrapper.
* Thu Nov  9 2017 ilya@ilya.pp.ua
- Refresh pppoe.spec via spec-cleaner.
* Sun Oct  8 2017 ilya@ilya.pp.ua
- Add pppoe.service for run pppoe as client (boo#1060710).
- Refresh pppoe.spec.
- Drop SLE 11 support.
* Wed Nov 16 2016 13ilya@gmail.com
- Fix patches and script for version 3.12.
- dropped logger-path.diff
- Add net-tools support. net-tools-deprecated is no longer required.
* Tue Oct 25 2016 13ilya@gmail.com
- Update to version 3.12.
- Fix patch release-buildsystem.diff for 3.12 version.
- Add to Requires net-tools-deprecated package.
- Reordered patch positions.
- Formated all the variables in the spec-file to macro style.
* Sat Oct 25 2014 p.drouand@gmail.com
- Use systemd instead of sysvinit; add pppoe-server.service
- Install fixed versions of rp-pppoe scripts for openSUSE > 11.4
  most of fixes are about paths, because of /usr move
  Added:  pppoe-setup, ,pppoe-start, pppoe-connect, pppoe-status ,
  pppoe-stop
* Tue Apr 23 2013 binli@opensuse.org
- update to version 3.11
  * Make the rp-pppoe.so plugin avoid calling exit() if
    the "persist" pppd option was given.
  * Get rid of hard-coded nobsdcomp, nodeflate, novj and novjccomp
    options in pppoe-server.
  * Handle UNIT=xxx directive in pppoe-connect.
  * Add "-i" flag to pppoe-server to ignore PADIs if there are
    no free sessions.
  * Add "-X <pidfile>" option to pppoe-server.
  * In plugin, don't set devnam if it's already set.
  * Eliminate race condition in signal handling.
  * pppoe-server: Add -q and -Q options to allow specification of
    path to pppd and pppoe programs respectively.
  * Add a few more sanity checks to pppoe-server packet handling.
* Tue Jan 24 2012 crrodriguez@opensuse.org
- build pppoe-wrapper with PIE and full RELRO
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Fri May  8 2009 chris@computersalat.de
- new patch for init script
  o added reload
  o rework of status
- added config patch
* Wed Apr 15 2009 chris@computersalat.de
- beautify spec
* Fri Jul  4 2008 hvogel@suse.de
- update to version 3.10
  * some compilation fixes
  * pppoe-server has new "-x" option to limit the number of sessions
    per MAC address.
  * Added proper timeout handling while waiting for PADO/PADS.
  * Fix race condition with some access concentrators
* Thu Feb 21 2008 crrodriguez@suse.de
- add missing remote_fs dependency in the init script
- fix/add missing calls to restart_on_update and stop_on_removal macros
* Thu Jul 13 2006 mskibbe@suse.de
- update to version 3.8 which
  o Adjusted code and made it possible to disable debugging code
    to shrink size of pppoe executable.
  o Fixed bug in MD5 code that caused pppoe-server to segfault on
    64-bit machines.
  o Made various functions and variables static that didn't need
    to be visible outside their source files.
* Fri May 26 2006 schwab@suse.de
- Use RPM_OPT_FLAGS.
- Don't strip binaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Nov 17 2005 arvin@suse.de
- updated to version 3.7
  - pppoe-server prepends "nic-" to interface name if used with
    kernel-mode plugin
  - added -O option to pppoe-server that specify a different
    default options file for pppd
* Wed Sep 21 2005 arvin@suse.de
- updated to version 3.6:
  - Changed the names of commands from adsl-* to pppoe-* to
    more logically name the scripts (incompatibility)
  - Changed sample firewall scripts to use iptables instead of
    the old ipchains command
* Wed Jan 19 2005 arvin@suse.de
- fixed build on s390 by compiling without -ansi
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Sep  5 2003 ro@suse.de
- fix typo in specfile
* Fri Sep  5 2003 kukuk@suse.de
- Add %%attr to get filelist in sync with /etc/permissions*
* Fri Jun 13 2003 nashif@suse.de
- Added %%dir to created directories
* Thu May 15 2003 nashif@suse.de
- Fixed init script syntax (bug #26248)
- Fixed file list
* Mon Mar 10 2003 nashif@suse.de
- dont link /etc/resolv.conf, done by ip-up ( #15707)
* Tue Oct  1 2002 nashif@suse.de
- Don't check for release file
* Mon Sep 30 2002 nashif@suse.de
- fixed bug #20327: wrong path to logger in scripts
* Mon Aug 19 2002 kukuk@suse.de
- fixed compilation on UL
* Sun Aug 18 2002 nashif@suse.de
- Fixed bug #17866: Added PreReq
* Sat Aug 10 2002 nashif@suse.de
- Fix bug #17465: detect non-rfc modems
- Fix bug #17466: use netfilter instead of ipchains
* Mon Jul 29 2002 nashif@suse.de
- update to 3.5
* Mon Jan 14 2002 ro@suse.de
- removed START_ADSL
* Sat Oct 20 2001 nashif@suse.de
- Update to 3.3
  * Client works on Solaris again.  It was broken in 3.2.
  * Added DEFAULTROUTE=yes|no option to configuration file.
  * Server parses address pool file better.
  * Server address pool allows ranges of addresses on a line: a.b.c.d-e
  * Added "-d" (=debug) and "-P" (=check pool file syntax) options to
    pppoe-server.
* Fri Aug  3 2001 nashif@suse.de
- Update to version 3.2
* Thu Jun 28 2001 nashif@suse.de
- Fixed bug #8966
- bzipped sources
* Sat Apr 21 2001 nashif@suse.de
- Fixed documentation path in GUI
- Added GUI documentation
* Thu Apr  5 2001 nashif@suse.de
- Fixed init script (Use rc_status)
* Tue Apr  3 2001 nashif@suse.de
- Update to version 3.0
* Thu Mar  1 2001 nashif@suse.de
- Update to version 2.8
- Fixed headers
* Fri Dec 22 2000 nashif@suse.de
- Added obosletes and provides tags
* Wed Dec 13 2000 nashif@suse.de
- Update to 2.5 (Fixes security problem)
* Sat Dec  9 2000 nashif@suse.de
- Update to 2.4
- Fix rcadsl link
- Changed name tp rp-pppoe
* Wed Nov 29 2000 nashif@suse.de
- Use insserv
* Fri Sep 22 2000 nashif@suse.de
- Updated to 2.3
* Thu May 25 2000 nashif@suse.de
- Updated to 1.9
- Added init script
* Sun May  7 2000 nashif@suse.de
- Update to version 1.8
* Wed Mar 29 2000 nashif@suse.de
- Update to version 1.7
- Fixed Group & Buildroot tag
* Wed Feb 23 2000 nashif@suse.de
- Initial Release (Version 1.3)
